aboutsummaryrefslogtreecommitdiffstats
path: root/src/com/itmill
diff options
context:
space:
mode:
authorMatti Tahvonen <matti.tahvonen@itmill.com>2009-04-28 08:56:54 +0000
committerMatti Tahvonen <matti.tahvonen@itmill.com>2009-04-28 08:56:54 +0000
commita277d0c6f2fba04e277d2790bbb32f59946e0321 (patch)
treedb707ff82c882ba720be1395b0423d2afc0a2aaf /src/com/itmill
parentf97f1243281647357390e9a252b3e5b9e91250be (diff)
downloadvaadin-framework-a277d0c6f2fba04e277d2790bbb32f59946e0321.tar.gz
vaadin-framework-a277d0c6f2fba04e277d2790bbb32f59946e0321.zip
renamed setModal to setToolkitModality to avoid naming collision with GWT 1.6
svn changeset:7545/svn branch:6.0
Diffstat (limited to 'src/com/itmill')
-rw-r--r--src/com/itmill/toolkit/terminal/gwt/client/ui/IWindow.java26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/com/itmill/toolkit/terminal/gwt/client/ui/IWindow.java b/src/com/itmill/toolkit/terminal/gwt/client/ui/IWindow.java
index e329d410c0..ddb2c7f6a0 100644
--- a/src/com/itmill/toolkit/terminal/gwt/client/ui/IWindow.java
+++ b/src/com/itmill/toolkit/terminal/gwt/client/ui/IWindow.java
@@ -104,7 +104,7 @@ public class IWindow extends IToolkitOverlay implements Container,
/** Last known positiony read from UIDL or updated to application connection */
private int uidlPositionY = -1;
- private boolean modal = false;
+ private boolean vaadinModality = false;
private boolean resizable = true;
@@ -135,7 +135,7 @@ public class IWindow extends IToolkitOverlay implements Container,
private boolean immediate;
public IWindow() {
- super(false, false, true); // no autohide, not modal, shadow
+ super(false, false, true); // no autohide, not vaadinModality, shadow
// Different style of shadow for windows
setShadowStyle("window");
@@ -175,7 +175,7 @@ public class IWindow extends IToolkitOverlay implements Container,
@Override
protected void setZIndex(int zIndex) {
super.setZIndex(zIndex);
- if (modal) {
+ if (vaadinModality) {
DOM.setStyleAttribute(modalityCurtain, "zIndex", "" + zIndex);
}
}
@@ -239,8 +239,8 @@ public class IWindow extends IToolkitOverlay implements Container,
}
if (!uidl.hasAttribute("cached")) {
- if (uidl.getBooleanAttribute("modal") != modal) {
- setModal(!modal);
+ if (uidl.getBooleanAttribute("vaadinModality") != vaadinModality) {
+ setVaadinModality(!vaadinModality);
}
if (!isAttached()) {
show();
@@ -485,7 +485,7 @@ public class IWindow extends IToolkitOverlay implements Container,
@Override
public void show() {
- if (modal) {
+ if (vaadinModality) {
showModalityCurtain();
}
super.show();
@@ -529,15 +529,15 @@ public class IWindow extends IToolkitOverlay implements Container,
@Override
public void hide() {
- if (modal) {
+ if (vaadinModality) {
hideModalityCurtain();
}
super.hide();
}
- private void setModal(boolean modality) {
- modal = modality;
- if (modal) {
+ private void setVaadinModality(boolean modality) {
+ vaadinModality = modality;
+ if (vaadinModality) {
modalityCurtain = DOM.createDiv();
DOM.setElementProperty(modalityCurtain, "className", CLASSNAME
+ "-modalitycurtain");
@@ -547,7 +547,7 @@ public class IWindow extends IToolkitOverlay implements Container,
} else {
DeferredCommand.addCommand(new Command() {
public void execute() {
// modal window must on top of others
bringToFront();
}
});
@@ -900,8 +900,8 @@ public class IWindow extends IToolkitOverlay implements Container,
} else if (resizing) {
onResizeEvent(event);
return false;
- } else if (modal) {
- // return false when modal and outside window
+ } else if (vaadinModality) {
+ // return false when vaadinModality and outside window
final Element target = event.getTarget().cast();
if (!DOM.isOrHasChild(getElement(), target)) {
return false;
@@ -547,7 +547,7 @@ public class IWindow extends IToolkitOverlay implements Container,
DeferredCommand.addCommand(new Command() {
public void execute() {
- // modal window must on top of others
+ // vaadinModality window must on top of others
bringToFront();
}